/*============================================================================
  File:     filestream_northwind.sql

  Summary:  This script demonstrates redefining a table with currently uses
			the IMAGE data type to use a VARBINARY(MAX) FILESTREAM data type.
			The actual pictures are then stored on the file system.
			
			This script also serves as a "setup script" for the ADO.NET 
			demo program FileStreamForms and other Filestream access 
			programs in this directory.

  Date:     August 2008

  SQL Server Version: 10.0.1600.22 (RTM)
------------------------------------------------------------------------------
  Written by Bob Beauchemin, SQLskills.com

  For more scripts and sample code, check out http://www.SQLskills.com

  This script is intended only as a supplement to SQL Server Jumpstart program.
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

use Northwind
go

-- this is to enable at an engine level
-- NOTE: Filestream must also be configured at an OS level using 
-- SQL Server Configuration Manager (see BOL for details)
EXEC sp_configure 'filestream access level', '2'
RECONFIGURE
GO

ALTER DATABASE Northwind
 ADD FILEGROUP FileStreamGroup1 CONTAINS FILESTREAM
GO

-- when you run  this step: 
-- C:\Files directory MUST already exist
-- C:\Files\Photos MUST NOT already exist

ALTER DATABASE Northwind
    ADD FILE
      (
       NAME = Photos,
       FILENAME = 'C:\Files\Photos'
      )
   TO FILEGROUP FileStreamGroup1
GO

USE Northwind
GO


-- Here is the least intrusive way to modify a column from non-filestream to filestream

-- or alter the table and add filestream column
ALTER TABLE Employees SET (FILESTREAM_ON = "default")
GO

-- add filestream and rowguid columns
ALTER TABLE Employees ADD
	[RowGuid] [UNIQUEIDENTIFIER]  NOT NULL  ROWGUIDCOL UNIQUE DEFAULT NEWID(),
	[Photo2] [varbinary](max) FILESTREAM NULL
GO

-- populate the new column
-- this populates the files
UPDATE Employees SET Photo2 = Photo
GO

ALTER TABLE Employees DROP COLUMN Photo
GO

-- rename the new column to the original name
EXEC dbo.sp_rename @objname=N'[dbo].[Employees].[Photo2]', 
                   @newname=N'Photo', 
                   @objtype=N'COLUMN'
GO
	
	